autowisp.tests.test_stack_to_master module — AutoWISP documentation

# autowisp.tests.test_stack_to_master module

## Class Inheritance Diagram

Test cases for master stacking.

class autowisp.tests.test_stack_to_master.TestStackToMaster(methodName='runTest')

  Bases: `FITSTestCase`

  Test cases for master stacking steps.

  _test_stack_to_master(master_type)

    Perform a stacking step and test outputs match expectations.

  test_stack_master_bias()

    Check if creating master bias works as expected.

  test_stack_master_dark()

    Check if creating master bias works as expected.

  test_stack_master_flat()

    Check if creating master bias works as expected.